Index: ticketstats/ticketstats.py
===================================================================
--- ticketstats/ticketstats.py	(revision 4518)
+++ ticketstats/ticketstats.py	(working copy)
@@ -14,6 +14,7 @@
 from genshi.builder import tag
 
 from trac.core import *
+from trac.config import Option, IntOption
 from trac.web import IRequestHandler
 from trac.web.chrome import INavigationContributor, ITemplateProvider
 from trac.perm import IPermissionRequestor
@@ -30,6 +31,19 @@
 class TicketStatsPlugin(Component):
 	implements(INavigationContributor, IRequestHandler, ITemplateProvider, IPermissionRequestor)
 
+	yui_base_url = Option('ticketstats', 'yui_base_url',
+			default='http://yui.yahooapis.com/2.5.2',
+			doc='Location of YUI API')
+
+	default_days_back = IntOption('ticketstats', 'default_days_back',
+			default=DEFAULT_DAYS_BACK,
+			doc='Number of days to show by default')
+
+	default_interval = IntOption('ticketstats', 'default_interval',
+			default=DEFAULT_INTERVAL,
+			doc='Number of days between each data point'\
+				' (resolution) by default')
+
 	# ==[ INavigationContributor methods ]==
 
 	def get_active_navigation_item(self, req):
@@ -143,14 +157,11 @@
 			graph_res = int(grab_resolution)
 
 		else:
-			global DEFAULT_DAYS_BACK 
-			global DEFAULT_INTERVAL
-
 			# default data
 			todays_date = date.today()
 			at_date = datetime.combine(todays_date,time(11,59,59,0,utc))
-			from_date = at_date - timedelta( DEFAULT_DAYS_BACK )
-			graph_res = DEFAULT_INTERVAL
+			from_date = at_date - timedelta(self.default_days_back)
+			graph_res = self.default_interval
 	
 			at_date_str = at_date.strftime("%m/%d/%Y")
 			from_date_str=  from_date.strftime("%m/%d/%Y")
@@ -185,6 +196,7 @@
 
 		data = {'chart_data': count}
 		
+		req.hdf['yui_base_url'] = self.yui_base_url
 		req.hdf['ticket_data'] = data
 		req.hdf['start_date'] = from_date.strftime("%m/%d/%Y")
 		req.hdf['end_date'] = at_date.strftime("%m/%d/%Y")
Index: ticketstats/templates/greensauce.cs
===================================================================
--- ticketstats/templates/greensauce.cs	(revision 4518)
+++ ticketstats/templates/greensauce.cs	(working copy)
@@ -5,14 +5,14 @@
 #chart { height: 500px }
 </style>
 
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/yahoo-dom-event/yahoo-dom-event.js"></script>
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/element/element-beta-min.js"></script>
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/datasource/datasource-beta-min.js"></script>
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/json/json-min.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/yahoo-dom-event/yahoo-dom-event.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/element/element-beta-min.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/datasource/datasource-beta-min.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/json/json-min.js"></script>
 <!-- OPTIONAL: Connection (enables XHR) -->
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/connection/connection-min.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/connection/connection-min.js"></script>
 <!-- Source files -->
-<script type="text/javascript" src="http://yui.yahooapis.com/2.5.2/build/charts/charts-experimental-min.js"></script>
+<script type="text/javascript" src="<?cs var:yui_base_url ?>/build/charts/charts-experimental-min.js"></script>
 <p>
 <span class="chart_title">
 	<h1>Ticket Statistics</h1>
@@ -29,7 +29,7 @@
 </form>
 
 <script type = "text/javascript">
-YAHOO.widget.Chart.SWFURL = "http://yui.yahooapis.com/2.5.2/build/charts/assets/charts.swf";
+YAHOO.widget.Chart.SWFURL = "<?cs var:yui_base_url ?>/build/charts/assets/charts.swf";
 
 
 var mychartdata = 
